@@ -2,8 +2,15 @@ NLGetPatches <-
 #function(patch.var, patchset="patches", as.matrix=FALSE, as.data.frame=FALSE, df.col.names=NULL, nl.obj=NULL)
 function(patch.var, patchset="patches", as.matrix=FALSE, as.data.frame=TRUE, patches.by.row=FALSE, as.vector=FALSE, nl.obj=NULL)
 {
+  # get internal nl.obj if NULL
   if (is.null(nl.obj))
-    nl.obj <- .rnetlogo[["nl.intern"]]
+  {
+    nl.obj <- "_nl.intern_"
+  }
+  # check for unknown nl.obj
+  if (!(nl.obj %in% names(.rnetlogo$objects))) {
+    stop(paste('There is no NetLogo reference stored under the name ',nl.obj,".", sep=""))
+  }  
 
   # check for empty patchset
   #if (NLReport(paste("count",patchset),nl.obj=nl.obj) == 0) {
